import os
import yaml
import click
import click_config_file
import jinja2
from twilio.rest import Client


def yaml_config_provider(file_path, cmd_name):
    with open(file_path) as f:
        confyaml = yaml.load(f)
        return dict(confyaml["config"])


@click.command()
# Optional parameters:
@click.option("-4", "--hostaddress", "hostaddress")
@click.option("-6", "--hostaddress6", "hostaddress6")
@click.option("-b", "--notificationauthorname", "notificationauthorname")
@click.option("-c", "--notificationcomment", "notificationcomment")
@click.option("-i", "--icingaweb2url", "icingaweb2url")
@click.option("-v", "--verbose", "verbose")
@click.option("-n", "--hostdisplayname", "hostdisplayname")
@click.option("-u", "--servicedisplayname", "servicedisplayname")
# Required parameters:
@click.option("-e", "--servicename", "servicename", required=True)
@click.option("-o", "--serviceoutput", "serviceoutput", required=True)
@click.option("-s", "--servicestate", "servicestate", required=True)
@click.option("-t", "--notificationtype", "notificationtype", required=True)
@click.option("-d", "--longdatetime", "longdatetime", required=True)
@click.option("-l", "--hostname", "hostname", required=True)
@click.option("--from", "twilio_from_number", required=True)
@click.option("--api-sid", "twilio_api_sid", required=True)
@click.option("--api-token", "twilio_api_token", required=True)
@click.option(
    "--to", "to_number", required=True, help="phone number the SMS should be sent to"
)
@click.option(
    "--template-dir",
    "template_dir",
    default=os.path.join(os.path.dirname(os.path.realpath(__file__)), "templates"),
    required=True,
)
@click_config_file.configuration_option(provider=yaml_config_provider)
def main(**kwargs):
    j2_env = jinja2.Environment(loader=jinja2.FileSystemLoader(kwargs["template_dir"]))

    sms = j2_env.get_template("sms_service.j2").render(
        hostname=kwargs["hostname"],
        hostdisplayname=kwargs["hostdisplayname"],
        servicename=kwargs["servicename"],
        serviceoutput=kwargs["serviceoutput"],
        servicestate=kwargs["servicestate"],
        notificationtype=kwargs["notificationtype"],
        servicedisplayname=kwargs["servicedisplayname"],
        longdatetime=kwargs["longdatetime"],
        hostaddress=kwargs["hostaddress"],
        hostaddress6=kwargs["hostaddress6"],
        notificationauthorname=kwargs["notificationauthorname"],
        notificationcomment=kwargs["notificationcomment"],
        icingaweb2url=kwargs["icingaweb2url"],
    )

    # Your Account Sid and Auth Token from twilio.com/console
    account_sid = kwargs["twilio_api_sid"]
    auth_token = kwargs["twilio_api_token"]

    client = Client(account_sid, auth_token)

    message = client.messages.create(
        body=sms, from_=kwargs["twilio_from_number"], to=kwargs["to_number"]
    )

    print(message.sid)


if __name__ == "__main__":
    main()
